__author__ = 'v.denisov'

import json
import os
from ptst_swagger.model.tests_to_swagger import TestsToSwagger


class SwaggerModel:

    def __init__(self):
        _record_test = None
        _record_test_list = None

    @property
    def record_test(self):
        return self._record_test

    @record_test.setter
    def set_record_test(self, value):
        self._record_test = value

    @property
    def record_test_list(self):
        return self._record_test_list

    @record_test_list.setter
    def set_record_test_list(self, r_list):
        self._record_test_list = r_list

    @classmethod
    def record_test_to_list(self, method, path, text):
        if not isinstance(method,str):
            method = str(method)
        if not isinstance(path,str):
            path = str(path)
        if not isinstance(text,str):
            text = str(text)

        if isinstance(self.record_test_list, property):
            self.record_test_list=[]
        r_list = self.record_test_list
        r_l_n = 0
        for r_l in r_list:
            if (r_l.method in method) and (r_l.path in path) and len(r_l.path)==len(path):
                r_list[r_l_n].text = str(int(r_l.text)+1)
                break
            r_l_n = r_l_n + 1
        else:
            r_list.append(TestsToSwagger(method=method, path=path, text=text))
        self.record_test_list = r_list

        file_type = os.path.join(os.getcwd(), 'tests.json')
        with open(file_type, 'w') as out:
            r_test_dict = []
            for r_test in self.record_test_list:
                r_test_dict.append({"method":r_test.method, "path":r_test.path, "text":r_test.text})
            json.dump(r_test_dict, out,  indent=4)



import allure
from ptst_swagger.config_host import ConfigHost as config
from ptst_swagger.client import SwaggerClient as client

@allure.title(" Тестируем ")
def test_t1():
    r = config.get_swagger_json(url='http://test.rais.d-net.pro:8080/bin/swagger/openapi.json')
    print('r=', r.json())
    r_path = client.get_paths_sw()
    print('r_path=', r_path)

@allure.title(" Тестируем ")
def test_t2():
    r = config.get_swagger_json(url='https://petstore.swagger.io/v2/swagger.json')
    print('r=', r.json())


__author__ = 'v.denisov'

from dataclasses import dataclass

@dataclass
class TestsToSwagger:
    method: str = None
    path: str = None
    text: str = None

# [
#   { "method": "POST", "path": "/v1/file", "text": "5" },
#   {"method": "GET", "path": "/system/health", "text": "2" }
# ]


import allure
#from ptst_swagger.client import SwaggerClient

@allure.title(" Тестируем  test_t2")
# @SwaggerClient.record_test("GET", '/test', '1')
def test_t2(rais):
    rais.record_test("GET", '/system/health', 1)
    rais.record_test("POST", '/v1/file', 1)
    rais.record_test("POST", '/v1/file', '1')
    rais.record_test("GET", '/v1/file/{id}/permission', '1')
    r = rais.get_paths_sw()
    for rx in r:
        print('rx=', rx)
    print('r=', r)
    r2 = rais.get()
    print('r2=', r2.cookies)
    response_user = rais.get(paths='/interface/orange/user/get')
    print('response_user=', response_user.cookies, response_user.json())

    payload = {'login': 'test@id-network.ru',
               'password': 'TestPassword'}
    headers = {
        'x-project-name': 'rais_lkp'
    }
    url = 'https://lkp.hypergraph.dev.k8s.id-network.ru'
    paths = '/golkp/api/auth/login'
    response = rais.post(url=url, paths=paths, data=payload, headers=headers)
    print("login_cooke=", response.cookies, response.json())



__author__ = 'v.denisov'

import allure
from ptst_swagger.config_host import ConfigHost as config
from ptst_swagger.reguest import RegustsHelper as rh
from ptst_swagger.swagger_model import SwaggerModel as swm

class SwaggerClient():

    def __init__(self):
        pass

    @classmethod
    @allure.step('get paths_sw')
    def get_paths_sw(self):
        return config.paths_sw

    @classmethod
    @allure.step('set url_host')
    def set_url_host(self, url_host):
        config.url_host = url_host

    @classmethod
    @allure.step('get url_host')
    def get_url_host(self):
        return config.url_host

    @classmethod
    @allure.step('set cookies')
    def set_cookies(self, cookies):
        config.cookies = cookies

    @classmethod
    @allure.step('get cookies')
    def get_cookies(self):
        return config.cookies

    @classmethod
    @allure.step('set headers')
    def set_headers(self, headers):
        config.headers = headers

    @classmethod
    @allure.step('get headers')
    def get_headers(self):
        return config.headers

    @classmethod
    def setting_parameters(cls, url, paths, cookies, headers):
        if isinstance(config.cookies, property):
            config.cookies = None
        if isinstance(config.headers, property):
            config.headers = None
        if url is None:
            url = config.url_host + paths
        else:
            url = url + paths
        if cookies is None:
            cookies = config.cookies
        if headers is None:
            headers = config.headers
        return url, cookies, headers

    @classmethod
    @allure.step('get')
    def get(self, url=None, paths='', cookies=None, params=None, headers=None):
        url, cookies, headers = self.setting_parameters(url, paths, cookies, headers)
        response = rh.get(url=url, cookies=cookies, params=params, headers=headers)
        return response

    @classmethod
    @allure.step('post')
    def post(self, url=None, paths='', cookies=None, data=None, params=None, headers=None, files=None):
        url, cookies, headers = self.setting_parameters(url, paths, cookies, headers)
        response = rh.post(url=url, cookies=cookies, data=data, params=params, headers=headers, files=files)
        return response

    @classmethod
    @allure.step('delete')
    def delete(self, url=None, paths='', cookies=None, data=None, params=None, headers=None, files=None):
        url, cookies, headers = self.setting_parameters(url, paths, cookies, headers)
        response = rh.delete(url=url, cookies=cookies, data=data, params=params, headers=headers, files=files)
        return response

    @classmethod
    @allure.step('options')
    def options(self, url=None, paths='', cookies=None, data=None, params=None, headers=None, files=None):
        url, cookies, headers = self.setting_parameters(url, paths, cookies, headers)
        response = rh.options(url=url, cookies=cookies, data=data, params=params, headers=headers, files=files)
        return response

    @classmethod
    @allure.step('head')
    def head(self, url=None, paths='', cookies=None, data=None, params=None, headers=None, files=None):
        url, cookies, headers = self.setting_parameters(url, paths, cookies, headers)
        response = rh.head(url=url, cookies=cookies, data=data, params=params, headers=headers, files=files)
        return response

    @classmethod
    @allure.step('put')
    def put(self, url=None, paths='', cookies=None, data=None, params=None, headers=None, files=None):
        url, cookies, headers = self.setting_parameters(url, paths, cookies, headers)
        response = rh.put(url=url, cookies=cookies, data=data, params=params, headers=headers, files=files)
        return response

    @classmethod
    @allure.step('patch')
    def patch(self, url=None, paths='', cookies=None, data=None, params=None, headers=None, files=None):
        url, cookies, headers = self.setting_parameters(url, paths, cookies, headers)
        response = rh.patch(url=url, cookies=cookies, data=data, params=params, headers=headers, files=files)
        return response

    @classmethod
    def record_test(self, method, path, text):
        if not type(swm.record_test) == int:
            swm.record_test = 0
        if swm.record_test:
            swm.record_test_to_list(method, path, text)

    @classmethod
    def inn_record_test(self):
        swm.record_test = 1






__author__ = 'v.denisov'

import allure
from ptst_swagger.reguest import RegustsHelper as rh


class ConfigHost():

    def __init__(self):
        self._paths_sw = None
        self._url_host = None
        self._cookies = None
        self._headers = None

    @property
    def paths_sw(self):
        return self._paths_sw

    @paths_sw.setter
    def set_paths_sw(self, value):
        self._paths_sw = value

    @property
    def url_host(self):
        return self._url_host

    @url_host.setter
    def set_url_host(self, value):
        self._url_host = value

    @property
    def cookies(self):
        return self._cookies

    @cookies.setter
    def set_cookies(self, value):
        self._cookies = value

    @property
    def headers(self):
        return self._headers

    @headers.setter
    def set_headers(self, value):
        self._headers = value

    @classmethod
    @allure.step("get swagger json")
    def get_swagger_json(self, url):
        swagger_response = rh.get(url=url)
        self.paths_sw = swagger_response.json()['paths']
        return swagger_response


__author__ = 'v.denisov'

import pytest
from ptst_swagger.config_host import ConfigHost as config
from ptst_swagger.client import SwaggerClient as client
from tests.test_rais.conftest2 import conftest2

@pytest.fixture()
def rais():
    config.get_swagger_json(url='http://test.rais.d-net.pro:8080/bin/swagger/openapi.json')
    config.url_host = "http://rais.dev.d-net.pro"
    conftest2()
    client.inn_record_test()
    return client


__author__ = 'v.denisov'

from ptst_swagger.config_host import ConfigHost as config
from ptst_swagger.client import SwaggerClient as client

def conftest2():
    config.cookies = None
    config.headers = None
    response = client.get(paths='/get_rsid')
    for cookie in response.cookies:
        if cookie.name in 'rsid':
            cookie_domain = cookie.domain
            break
    cookies_jar = response.cookies
    cookies_jar.set('profile', "594b94fd-0000-0000-0000-00001e4bdc4c", domain=cookie_domain)
    config.cookies = cookies_jar
    print('config.cookies=', config.cookies)
    data ={
        "login": "rais.test",
        "pass" : "qazwiox",
        "lang" : "RU"
    }
    headers = {
        "X-Project-Name": "rais"
    }
    response_login = client.post(paths='/interface/orange/user/login', data=data, headers=headers)
    print('response_login=', response_login.json())
